The AI Explainability 360 toolkit is an open-source library that supports interpretability and explainability of data and machine learning models. The AI Explainability 360 Python package includes a comprehensive set of algorithms that cover different dimensions of explanations along with proxy explainability metrics. 

We have developed the package with extensibility in mind. This library is still in development. We encourage the contribution of your explainability algorithms and metrics.
